@@ -19,7 +19,7 @@ svg.bboxLight <- function(x = c(1,1,1), col = '#FFFFDD', intensity = 1, distance
 		# Add vertices
 		svgviewr_env$svg$bboxLight[[add_at]] <- list()
 		svgviewr_env$svg$bboxLight[[add_at]]$x <- x[i,]
-		svgviewr_env$svg$bboxLight[[add_at]]$col <- webColor(col)
+		svgviewr_env$svg$bboxLight[[add_at]]$col <- setNames(webColor(col), NULL)
 		svgviewr_env$svg$bboxLight[[add_at]]$intensity <- intensity
 		svgviewr_env$svg$bboxLight[[add_at]]$distance <- distance
 		svgviewr_env$svg$bboxLight[[add_at]]$hidden <- hidden
