@@ -1,6 +1,6 @@
 svgviewr.points <- function(x, file=NULL, y=NULL, type="p", col=NULL, col.fill="black", 
 	col.stroke="black", z.index=0, layer="", label="", cex=2, lwd=2, opacity.stroke=1, 
-	opacity.fill=1, animate=NULL, append=TRUE, tag.name="point"){
+	opacity.fill=1, append=TRUE, tag.name="point"){
 
 	# IF Y IS NON-NULL, ADD AS SECOND COLUMN TO X
 	if(!is.null(y)) x <- cbind(x, y)
@@ -59,7 +59,11 @@ svgviewr.points <- function(x, file=NULL, y=NULL, type="p", col=NULL, col.fill="
 		zc <- paste(x[i, 3, ], collapse=",")
 
 		# CHECK THAT POINTS CHANGE POSITION BEFORE PRINTING ANIMATION STRING
-		sum_sd <- sum(apply(matrix(x[i, , ], ncol=3, byrow=T), 2, sd))
+		sum_sd <- 0
+		if(is.matrix(x[i, , ])){
+			sum_sd <- sum(abs(diff(x[i, 1, ]))) + sum(abs(diff(x[i, 2, ]))) + sum(abs(diff(x[i, 3, ])))
+		}else{
+		}
 		if(!is.na(sum_sd) && sum_sd == 0){
 			xc <- x[i, 1, 1]
 			yc <- x[i, 2, 1]
@@ -70,17 +74,21 @@ svgviewr.points <- function(x, file=NULL, y=NULL, type="p", col=NULL, col.fill="
 			"\" ", cp, "x=\"", xc, "\" ", cp, 
 			"y=\"", yc, "\" ", cp, 
 			"z=\"", zc, 
-			"\" label=\"", label[i], "\" r=\"", cex[i], "\" stroke=\"", col.stroke[i], 
-			"\" stroke-width=\"", lwd[i], "\" fill=\"", col.fill[i], "\" fill-opacity=\"", opacity.fill[i], 
-			"\" stroke-opacity=\"", opacity.stroke[i], "\" />", sep="")
+			"\" label=\"", label[i], "\" r=\"", cex[i], "\" stroke=\"", webColor(col.stroke[i]), 
+			"\" stroke-width=\"", lwd[i], "\" fill=\"", webColor(col.fill[i]), 
+			"\" fill-opacity=\"", opacity.fill[i], "\" stroke-opacity=\"", 
+			opacity.stroke[i], "\" ></", tag.name, ">", sep="")
 	}
 
 	# REMOVE SCIENTIFIC NOTATION
 	options(scipen=0)
 
+	# REMOVE NA LINES
+	new_lines <- new_lines[!is.na(new_lines)]
+
 	# IF FILE IS NULL, RETURN LINES OF SVG OBJECTS
 	if(is.null(file)) return(new_lines)
-
+	
 	# SAVE NEW LINES TO FILE
 	svgviewr.write(new_lines, file, append=append)
 }
\ No newline at end of file
